==> haskell-configfile-1.1.4-175-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ConfigFile
version:              1.1.4
visibility:           public
id:                   ConfigFile-1.1.4-CGI16qU6Snh7H9kkKjPvCb
key:                  ConfigFile-1.1.4-CGI16qU6Snh7H9kkKjPvCb
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2014 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Stable
homepage:             http://software.complete.org/configfile
synopsis:             Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.

    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.

    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.

category:             Parsing
abi:                  ca033c2ea3d74294d0c8c8d8b0107d0d
exposed:              True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types

hidden-modules:       Data.ConfigFile.Lexer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configfile
hs-libraries:         HSConfigFile-1.1.4-CGI16qU6Snh7H9kkKjPvCb
depends:
    MissingH-1.6.0.2-E9ofqzQOzrG9iF5Mtpv8d5 base-4.17.2.1
    containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1

haddock-interfaces:   /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html:         /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configfile-1.1.4-176-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ConfigFile
version:              1.1.4
visibility:           public
id:                   ConfigFile-1.1.4-1ezozXGQQbxFdFkmLcWdYW
key:                  ConfigFile-1.1.4-1ezozXGQQbxFdFkmLcWdYW
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2014 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Stable
homepage:             http://software.complete.org/configfile
synopsis:             Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.

    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.

    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.

category:             Parsing
abi:                  49759fd1650b1e1b45999b34fb472024
exposed:              True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types

hidden-modules:       Data.ConfigFile.Lexer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configfile
hs-libraries:         HSConfigFile-1.1.4-1ezozXGQQbxFdFkmLcWdYW
depends:
    MissingH-1.6.0.2-JNfVjzLwLmslKL5kpbO2M base-4.17.2.1
    containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1

haddock-interfaces:   /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html:         /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
